DiagnosticProperty<T> class abstract

A typed property contributed by a Diagnosticable object.

Implementers

Constructors

DiagnosticProperty(String name, T value, {DiagnosticsLevel level = DiagnosticsLevel.info})
Creates a typed property.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
level → DiagnosticsLevel
Display severity.
final
name String
Property label on the diagnostics wire.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
Strongly typed value before wire conversion.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toContract() → DiagnosticsProperty
Converts this typed object to the versioned contract union.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited