DiagnosticsTreeWalker class final

Projects a mounted genesis tree into the version-1 semantic diagnostics tree.

Constructors

DiagnosticsTreeWalker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
walk(Branch root, {required DateTime projectedAt}) → TreeSnapshot
Walks root without mutating or subscribing to it.

Operators

operator ==(Object other) bool
The equality operator.
inherited