Failed class

The capability failed (routes to supervision). Maps to StepState.failed.

Inheritance

Constructors

Failed([String reason = ''])
Creates a failure with an optional reason (diagnostics).
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
A human-readable failure reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited