LandedDeliveryTotals class abstract

Landed-delivery components retained for lossless projection merges.

Available extensions
Annotations
  • @freezed

Constructors

LandedDeliveryTotals({@Default.new(0) double landedCost, @Default.new(0) int landedCount})
Creates landed-delivery totals.
const
factory

Properties

copyWith → $LandedDeliveryTotalsCopyWith<LandedDeliveryTotals>
Create a copy of LandedDeliveryTotals with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
landedCost double
Cost in US dollars across landed sessions.
no setterinherited
landedCount int
Number of sessions with a non-empty delivery.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LandedDeliveryTotals value)) → TResult

Available on LandedDeliveryTotals, provided by the LandedDeliveryTotalsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LandedDeliveryTotals value)?) → TResult?

Available on LandedDeliveryTotals, provided by the LandedDeliveryTotalsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LandedDeliveryTotals value)?, {required TResult orElse()}) → TResult

Available on LandedDeliveryTotals, provided by the LandedDeliveryTotalsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(double landedCost, int landedCount)?, {required TResult orElse()}) → TResult

Available on LandedDeliveryTotals, provided by the LandedDeliveryTotalsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(double landedCost, int landedCount)) → TResult

Available on LandedDeliveryTotals, provided by the LandedDeliveryTotalsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(double landedCost, int landedCount)?) → TResult?

Available on LandedDeliveryTotals, provided by the LandedDeliveryTotalsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited