LeaseDeniedException class

Thrown when a lessor REFUSES a lease (no capacity / not offered / the wait-queue is full or the wait expired) — the declare-and-check denial (HTTP 409).

Inheritance

Constructors

LeaseDeniedException(String reason)
Creates a denial carrying reason.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited