MetricsDecodeIssue class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- beadId → String
-
no setterinherited
-
copyWith
→ $MetricsDecodeIssueCopyWith<
MetricsDecodeIssue> -
Create a copy of MetricsDecodeIssue
with the given fields replaced by the non-null parameter values.
no setterinherited
- field → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodePath → String?
-
no setterinherited
- reason → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
no setterinherited
- wireValue → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_MetricsDecodeIssue value)) → TResult -
Available on MetricsDecodeIssue, provided by the MetricsDecodeIssuePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_MetricsDecodeIssue value)?) → TResult? -
Available on MetricsDecodeIssue, provided by the MetricsDecodeIssuePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_MetricsDecodeIssue value)?, {required TResult orElse()}) → TResult -
Available on MetricsDecodeIssue, provided by the MetricsDecodeIssuePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String beadId, String? sessionId, String? nodePath, String field, String wireValue, String reason)?, {required TResult orElse()}) → TResult -
Available on MetricsDecodeIssue, provided by the MetricsDecodeIssuePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String beadId, String? sessionId, String? nodePath, String field, String wireValue, String reason)) → TResult -
Available on MetricsDecodeIssue, provided by the MetricsDecodeIssuePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String beadId, String? sessionId, String? nodePath, String field, String wireValue, String reason)?) → TResult? -
Available on MetricsDecodeIssue, provided by the MetricsDecodeIssuePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited