MountEligibilityDecision class sealed

The content-gate decision returned by MountEligibilityPredicate.

Available extensions
Annotations
  • @freezed

Constructors

MountEligibilityDecision.eligible()
The candidate may cross the content gate.
const
factory
MountEligibilityDecision.refused({required String clause})
The candidate is excluded by the named clause.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult eligible(MountEligible value), required TResult refused(MountRefused value)}) → TResult

Available on MountEligibilityDecision, provided by the MountEligibilityDecisionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? eligible(MountEligible value)?, TResult? refused(MountRefused value)?}) → TResult?

Available on MountEligibilityDecision, provided by the MountEligibilityDecisionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult eligible(MountEligible value)?, TResult refused(MountRefused value)?, required TResult orElse()}) → TResult

Available on MountEligibilityDecision, provided by the MountEligibilityDecisionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult eligible()?, TResult refused(String clause)?, required TResult orElse()}) → TResult

Available on MountEligibilityDecision, provided by the MountEligibilityDecisionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult eligible(), required TResult refused(String clause)}) → TResult

Available on MountEligibilityDecision, provided by the MountEligibilityDecisionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? eligible()?, TResult? refused(String clause)?}) → TResult?

Available on MountEligibilityDecision, provided by the MountEligibilityDecisionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited