Ok class

The capability succeeded, optionally carrying a payload (e.g. a PR url) the engine may record. Maps to StepState.complete.

Inheritance

Constructors

Ok([Map<String, String>? payload])
Creates a success, optionally carrying payload.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload Map<String, String>?
An optional result payload (recorded on the session bead, never used as a pipeline signal).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited