ProcessSessionCommandPatterns extension

Adds pattern-matching-related methods to ProcessSessionCommand.

on

Methods

map<TResult extends Object?>(TResult $default(_ProcessSessionCommand value)) → TResult

Available on ProcessSessionCommand, provided by the ProcessSessionCommandPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ProcessSessionCommand value)?) → TResult?

Available on ProcessSessionCommand, provided by the ProcessSessionCommandPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ProcessSessionCommand value)?, {required TResult orElse()}) → TResult

Available on ProcessSessionCommand, provided by the ProcessSessionCommandPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String commandId, String attemptId, String instanceFence, String body)?, {required TResult orElse()}) → TResult

Available on ProcessSessionCommand, provided by the ProcessSessionCommandPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String commandId, String attemptId, String instanceFence, String body)) → TResult

Available on ProcessSessionCommand, provided by the ProcessSessionCommandPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String commandId, String attemptId, String instanceFence, String body)?) → TResult?

Available on ProcessSessionCommand, provided by the ProcessSessionCommandPatterns extension

A variant of when that fallback to returning null