SessionLedgerMetricsProjection class abstract

Available extensions
Annotations
  • @freezed

Constructors

SessionLedgerMetricsProjection({@Default.new(<String, LedgerSessionMetrics>{}) Map<String, LedgerSessionMetrics> sessionsById, @Default.new(<String, List<LedgerSessionMetrics>>{}) Map<String, List<LedgerSessionMetrics>> sessionsByLane, @Default.new(FalseFMetrics()) FalseFMetrics falseFs, @Default.new(CacheTokenTotals()) CacheTokenTotals cacheTokens, double? cacheHitRatio, @Default.new(<String, int>{}) Map<String, int> reworkRoundsByWorkBead, @Default.new(LandedDeliveryTotals()) LandedDeliveryTotals landedDeliveries, double? costPerLandedDelivery, @Default.new(<String, Map<LedgerGrade, int>>{}) Map<String, Map<LedgerGrade, int>> gradeDistributionByLane, @Default.new(<MetricsDecodeIssue>[]) List<MetricsDecodeIssue> issues})
const
factory

Properties

cacheHitRatio double?
no setterinherited
cacheTokens CacheTokenTotals
Components used to derive cacheHitRatio.
no setterinherited
copyWith → $SessionLedgerMetricsProjectionCopyWith<SessionLedgerMetricsProjection>
Create a copy of SessionLedgerMetricsProjection with the given fields replaced by the non-null parameter values.
no setterinherited
costPerLandedDelivery double?
no setterinherited
falseFs FalseFMetrics
no setterinherited
gradeDistributionByLane Map<String, Map<LedgerGrade, int>>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
issues List<MetricsDecodeIssue>
no setterinherited
landedDeliveries LandedDeliveryTotals
Components used to derive costPerLandedDelivery.
no setterinherited
reworkRoundsByWorkBead Map<String, int>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionsById Map<String, LedgerSessionMetrics>
no setterinherited
sessionsByLane Map<String, List<LedgerSessionMetrics>>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SessionLedgerMetricsProjection value)) → TResult

Available on SessionLedgerMetricsProjection, provided by the SessionLedgerMetricsProjectionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SessionLedgerMetricsProjection value)?) → TResult?

Available on SessionLedgerMetricsProjection, provided by the SessionLedgerMetricsProjectionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SessionLedgerMetricsProjection value)?, {required TResult orElse()}) → TResult

Available on SessionLedgerMetricsProjection, provided by the SessionLedgerMetricsProjectionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<String, LedgerSessionMetrics> sessionsById, Map<String, List<LedgerSessionMetrics>> sessionsByLane, FalseFMetrics falseFs, CacheTokenTotals cacheTokens, double? cacheHitRatio, Map<String, int> reworkRoundsByWorkBead, LandedDeliveryTotals landedDeliveries, double? costPerLandedDelivery, Map<String, Map<LedgerGrade, int>> gradeDistributionByLane, List<MetricsDecodeIssue> issues)?, {required TResult orElse()}) → TResult

Available on SessionLedgerMetricsProjection, provided by the SessionLedgerMetricsProjectionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Map<String, LedgerSessionMetrics> sessionsById, Map<String, List<LedgerSessionMetrics>> sessionsByLane, FalseFMetrics falseFs, CacheTokenTotals cacheTokens, double? cacheHitRatio, Map<String, int> reworkRoundsByWorkBead, LandedDeliveryTotals landedDeliveries, double? costPerLandedDelivery, Map<String, Map<LedgerGrade, int>> gradeDistributionByLane, List<MetricsDecodeIssue> issues)) → TResult

Available on SessionLedgerMetricsProjection, provided by the SessionLedgerMetricsProjectionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<String, LedgerSessionMetrics> sessionsById, Map<String, List<LedgerSessionMetrics>> sessionsByLane, FalseFMetrics falseFs, CacheTokenTotals cacheTokens, double? cacheHitRatio, Map<String, int> reworkRoundsByWorkBead, LandedDeliveryTotals landedDeliveries, double? costPerLandedDelivery, Map<String, Map<LedgerGrade, int>> gradeDistributionByLane, List<MetricsDecodeIssue> issues)?) → TResult?

Available on SessionLedgerMetricsProjection, provided by the SessionLedgerMetricsProjectionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited