EmptyBeadProbeReader class final

Empty lifecycle reader for mutation-only fixtures.

Constructors

EmptyBeadProbeReader()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beadById(String id, {required Set<IssueType> types}) Future<Bead?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBeads({required Set<IssueType> types, Map<String, String> metadataAll = const {}, Map<String, String> metadataAny = const {}}) Future<List<Bead>>
openSuperseding(Set<String> priorIds) Future<List<Bead>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited