createState method
Creates the mutable state for a branch of this seed.
Implementation
@override
State<FakeCapabilityHost> createState() => _FakeCapabilityHostState();
Creates the mutable state for a branch of this seed.
@override
State<FakeCapabilityHost> createState() => _FakeCapabilityHostState();