startGate property
A gate the test can hold to delay a start (proves the spawn ordering /
races); when null, start completes immediately.
Implementation
Completer<void>? startGate;
A gate the test can hold to delay a start (proves the spawn ordering /
races); when null, start completes immediately.
Completer<void>? startGate;