FakeSnapshotSource constructor
FakeSnapshotSource([
- GraphSnapshot? _current
Creates the fake source with an optional initial current.
Implementation
FakeSnapshotSource([this._current]);
Creates the fake source with an optional initial current.
FakeSnapshotSource([this._current]);