current property
The most recent snapshot, or null before the first baseline.
Implementation
@override
GraphSnapshot? get current => _current;
The most recent snapshot, or null before the first baseline.
@override
GraphSnapshot? get current => _current;