branchId property
Stable id of the bound branch, issued by TreeOwner.issueId at mount.
Throws StateError after the bound branch unmounts.
Implementation
@override
String get branchId => 'fake-branch';
Stable id of the bound branch, issued by TreeOwner.issueId at mount.
Throws StateError after the bound branch unmounts.
@override
String get branchId => 'fake-branch';