markNeedsRebuild method
Marks the bound branch dirty for the next TreeOwner.flush.
Throws StateError after the bound branch unmounts.
Implementation
@override
void markNeedsRebuild() {}
Marks the bound branch dirty for the next TreeOwner.flush.
Throws StateError after the bound branch unmounts.
@override
void markNeedsRebuild() {}