GatedCreateBdRunner class
A BdRunner whose create parks until releaseCreate is called, so a test
can drive a dispose into the middle of the async mint.
Constructors
Properties
- createPending → bool
-
True while a
createis parked awaiting releaseCreate.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseCreate(
String id) → void -
Resolves the in-flight
createwithid. -
run(
List< String> args, {Duration? timeout, String? stdin}) → Future<BdResult> -
Runs
bd <args>. ThrowsBdTimeoutExceptionif the call exceedstimeout(the implementation kills the process tree); never throws for a non-zero exit — that is reported viaBdResult.exitCodefor the caller to route throughBdCommandFailed.fromOutput. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited